qnupload
===========================

This Tools can help you to upload your file to QiNiu cloud storage.
You can install this easily,

    python setup.py install

And you can get help message by run:

    qnupload -h
